@@ -11,13 +11,12 @@
 #include "periodictableview.h"
 
 #include <QTimer>
-#include <QSvgGenerator>
 
 #include "psetables.h"
 #include <prefs.h>
 
 PeriodicTableView::PeriodicTableView(QWidget *parent)
-        : QGraphicsView(parent)
+    : QGraphicsView(parent)
 {
     setRenderHint(QPainter::Antialiasing);
     setViewportUpdateMode(QGraphicsView::BoundingRectViewportUpdate);
@@ -31,19 +30,17 @@ PeriodicTableView::PeriodicTableView(QWidget *parent)
     setScene(m_tableScene);
     connect(m_tableScene, &PeriodicTableScene::freeSpaceClick, this, &PeriodicTableView::fitPseInView);
 
-    m_tableStates = new PeriodicTableStates(
-        createElementItems(),
-        createNumerationItems());
+    m_tableStates = new PeriodicTableStates(createElementItems(), createNumerationItems());
 
     fitPseInView();
 }
 
-QList<NumerationItem*> PeriodicTableView::createNumerationItems() const
+QList<NumerationItem *> PeriodicTableView::createNumerationItems() const
 {
     // Creating Nummerationitems here, we use the classic periodic table as reference (18 elements in a row)
     const int xMax = 18;
 
-    QList<NumerationItem*> numerationItemList;
+    QList<NumerationItem *> numerationItemList;
 
     for (int i = 0; i < xMax; ++i) {
         numerationItemList << new NumerationItem(i);
@@ -54,13 +51,13 @@ QList<NumerationItem*> PeriodicTableView::createNumerationItems() const
     return numerationItemList;
 }
 
-QList<ElementItem*> PeriodicTableView::createElementItems() const
+QList<ElementItem *> PeriodicTableView::createElementItems() const
 {
-    QList<ElementItem*> elementItemList;
+    QList<ElementItem *> elementItemList;
     KalziumElementProperty *elProperty = KalziumElementProperty::instance();
 
     foreach (int intElement, pseTables::instance()->getTabletype(0)->elements()) {
-        ElementItem *item = new ElementItem(elProperty, intElement);
+        auto item = new ElementItem(elProperty, intElement);
 
         connect(elProperty, &KalziumElementProperty::propertyChanged, item, &ElementItem::redraw);
         m_tableScene->addItem(item);
@@ -70,9 +67,9 @@ QList<ElementItem*> PeriodicTableView::createElementItems() const
     return elementItemList;
 }
 
-PeriodicTableScene* PeriodicTableView::pseScene() const
+PeriodicTableScene *PeriodicTableView::pseScene() const
 {
-    return  m_tableScene;
+    return m_tableScene;
 }
 
 int PeriodicTableView::table() const
@@ -127,7 +124,7 @@ void PeriodicTableView::setBiggerSceneRect()
     setSceneRect(newRect);
 }
 
-void PeriodicTableView::resizeEvent (QResizeEvent * event)
+void PeriodicTableView::resizeEvent(QResizeEvent *event)
 {
     fitPseInView();
     QGraphicsView::resizeEvent(event);
@@ -147,9 +144,9 @@ bool PeriodicTableView::event(QEvent *e)
     return QGraphicsView::event(e);
 }
 
-void PeriodicTableView::generateSvg(const QString& filename)
+void PeriodicTableView::generateSvg(const QString &filename)
 {
-    QSvgGenerator *svgGen = new QSvgGenerator();
+    auto svgGen = new QSvgGenerator();
     svgGen->setFileName(filename);
 
     QPainter painter;
@@ -166,4 +163,3 @@ PeriodicTableView::~PeriodicTableView()
     delete scene();
     delete m_tableStates;
 }
-
