@@ -16,27 +16,26 @@
 #include "kalziumdataobject.h"
 #include "search.h"
 
-SearchWidget::SearchWidget(QWidget *parent) : QWidget(parent), m_timer(nullptr)
+SearchWidget::SearchWidget(QWidget *parent)
+    : QWidget(parent)
+    , m_searchLine(new KLineEdit(this))
 {
-    QHBoxLayout *mainlay = new QHBoxLayout(this);
+    auto mainlay = new QHBoxLayout(this);
     mainlay->setContentsMargins(2, 2, 2, 2);
     mainlay->setSpacing(5);
 
-    m_searchLine = new KLineEdit(this);
     m_searchLine->setClearButtonEnabled(true);
     m_searchLine->setPlaceholderText(i18n("Search..."));
     m_searchLine->setTrapReturnKey(true);
-    connect(m_searchLine, &QLineEdit::textChanged,
-             this, &SearchWidget::searchTextChanged);
-    connect(m_searchLine, SIGNAL(returnPressed()),
-             this, SLOT(slotReturnPressed()));
+    connect(m_searchLine, &QLineEdit::textChanged, this, &SearchWidget::searchTextChanged);
+    connect(m_searchLine, SIGNAL(returnPressed()), this, SLOT(slotReturnPressed()));
     mainlay->addWidget(m_searchLine);
 }
 
 SearchWidget::~SearchWidget()
 {
-  delete m_searchLine;
-  delete m_timer;
+    delete m_searchLine;
+    delete m_timer;
 }
 
 void SearchWidget::giveFocus()
@@ -45,7 +44,7 @@ void SearchWidget::giveFocus()
     m_searchLine->setCursorPosition(m_searchLine->text().length());
 }
 
-void SearchWidget::searchTextChanged(const QString&)
+void SearchWidget::searchTextChanged(const QString &)
 {
     if (m_timer) {
         m_timer->stop();
